@@ -220,13 +220,13 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 		self._data.close()
 		for cleanupPath in self._cleanupPathList:
 			if isfile(cleanupPath):
-				log.debug(f"Removing file {cleanupPath}")
+				log.debug(f"cleanup: removing file {cleanupPath}")
 				try:
 					os.remove(cleanupPath)
 				except Exception:
 					log.exception(f"error removing {cleanupPath}")
 			elif isdir(cleanupPath):
-				log.debug(f"Removing directory {cleanupPath}")
+				log.debug(f"cleanup: removing directory {cleanupPath}")
 				rmtree(cleanupPath)
 			else:
 				log.error(f"no such file or directory: {cleanupPath}")
@@ -348,7 +348,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 		if name in self._entryFiltersName:
 			return
 		self._entryFilters.append(
-			StripFullHtml(  # pyright: ignore[reportArgumentType]
+			StripFullHtml(
 				self,
 				errorHandler=errorHandler,
 			),
@@ -395,10 +395,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 
 	def __str__(self) -> str:
 		return (
-			"Glossary{"
-			f"filename: {self._filename!r}"
-			f", name: {self._info.get('name')!r}"
-			"}"
+			f"Glossary{{filename: {self._filename!r}, name: {self._info.get('name')!r}}}"
 		)
 
 	def _loadedEntryGen(self) -> Iterator[EntryType]:
@@ -416,12 +413,12 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 			return
 
 		self.progressInit("Writing")
-		for _entry in iterable:
-			entry = _entry
+		for entry_ in iterable:
+			entry = entry_
 			for f in filters:
-				entry = f.run(entry)  # type: ignore # pyright: ignore[reportArgumentType]
+				entry = f.run(entry)  # type: ignore
 				# assert entry  # TODO: measure running time in non-optimized mode
-			yield entry  # pyright: ignore[reportReturnType]
+			yield entry
 		self.progressEnd()
 
 	def _readersEntryGen(self) -> Iterator[EntryType]:
@@ -624,10 +621,10 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 
 	def newDataEntry(self, fname: str, data: bytes) -> EntryType:
 		if self._readers:
-			return DataEntry(fname, data)  # pyright: ignore[reportReturnType]
+			return DataEntry(fname, data)
 
 		if self._tmpDataDir:
-			return DataEntry(  # pyright: ignore[reportReturnType]
+			return DataEntry(
 				fname,
 				data,
 				tmpPath=join(self._tmpDataDir, fname.replace("/", "_")),
@@ -636,7 +633,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 		tmpDir = join(cacheDir, "tmp")
 		os.makedirs(tmpDir, mode=0o700, exist_ok=True)
 		self._cleanupPathList.add(tmpDir)
-		return DataEntry(  # pyright: ignore[reportReturnType]
+		return DataEntry(
 			fname,
 			data,
 			tmpPath=join(tmpDir, uuid1().hex),
@@ -654,7 +651,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 		self,
 		formatName: str,
 		options: dict[str, Any],
-	) -> Any:  # noqa: ANN401
+	) -> Any:
 		readerClass = PluginHandler.plugins[formatName].readerClass
 		if readerClass is None:
 			raise ReadError("_createReader: readerClass is None")
@@ -695,7 +692,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 				)
 				del options[key]
 
-	def _openReader(self, reader: Any, filename: str) -> None:  # noqa: ANN401
+	def _openReader(self, reader: Any, filename: str) -> None:
 		# reader.open returns "Iterator[tuple[int, int]] | None"
 		progressbar: bool = self.progressbar
 		try:
@@ -721,7 +718,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 	def directRead(
 		self,
 		filename: str,
-		**options,  # noqa: ANN003
+		**options: Any,
 	) -> bool:
 		self._read(
 			filename=filename,
@@ -738,7 +735,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 		format: str | None = None,  # to be removed in 6.0.0 # noqa: A002
 		formatName: str = "",
 		direct: bool = False,
-		**options,  # noqa: ANN003
+		**options: Any,
 	) -> None:
 		if format:
 			warnings.warn(
@@ -793,7 +790,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 		self._readers.append(reader)
 		self._iter = self._readersEntryGen()
 
-	def loadReader(self, reader: Any) -> None:  # noqa: ANN401
+	def loadReader(self, reader: Any) -> None:
 		"""
 		Iterate over `reader` object and loads the whole data into self._data
 		must call `reader.open(filename)` before calling this function.
@@ -819,7 +816,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 		self,
 		formatName: str,
 		options: dict[str, Any],
-	) -> Any:  # noqa: ANN401
+	) -> Any:
 		validOptions = PluginHandler.formatsWriteOptions.get(formatName)
 		if validOptions is None:
 			raise WriteError(f"No write support for {formatName!r} format")
@@ -922,7 +919,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 		if self._config.get("save_info_json", False):
 			from .info_writer import InfoWriter
 
-			infoWriter = InfoWriter(self)  # pyright: ignore
+			infoWriter = InfoWriter(self)
 			infoWriter.setWriteOptions(options)
 			filenameNoExt, _, _, _ = splitFilenameExt(filename)
 			infoWriter.open(f"{filenameNoExt}.info")
@@ -941,7 +938,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 
 	@staticmethod
 	def _openWriter(
-		writer: Any,  # noqa: ANN401
+		writer: Any,
 		filename: str,
 	) -> None:
 		try:
@@ -954,9 +951,12 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 		filename: str,
 		formatName: str,
 		sort: bool = False,
-		**options,  # noqa: ANN003
+		**options: Any,
 	) -> str:
+		filenameOrig = filename
 		filename = os.path.abspath(filename)
+		if filenameOrig.endswith(os.sep):
+			filename += os.sep
 
 		if formatName not in PluginHandler.plugins:
 			raise WriteError(f"No plugin {formatName!r} was found")
@@ -1022,7 +1022,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 			log.info(f"Removing and re-creating {sq_fpath!r}")
 			os.remove(sq_fpath)
 
-		self._data = SqEntryList(  # pyright: ignore[reportAttributeAccessIssue]
+		self._data = SqEntryList(
 			entryToRaw=self._entryToRaw,
 			entryFromRaw=self._entryFromRaw,
 			database=sq_fpath,
@@ -1109,7 +1109,7 @@ class GlossaryCommon(GlossaryInfo, GlossaryProgress):  # noqa: PLR0904
 				inputFilename=args.inputFilename,
 			)
 		elif not os.getenv("NO_SQLITE"):
-			self._data = self._newInMemorySqEntryList()  # pyright: ignore
+			self._data = self._newInMemorySqEntryList()
 
 		self._data.setSortKey(
 			namedSortKey=namedSortKey,
