@@ -18,6 +18,7 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
+from __future__ import annotations
 
 import logging
 import re
@@ -92,7 +93,7 @@ class MDict:
 		self,
 		fname: str,
 		encoding: str = "",
-		passcode: "tuple[bytes, bytes] | None" = None,
+		passcode: tuple[bytes, bytes] | None = None,
 	) -> None:
 		self._fname = fname
 		self._encoding = encoding.upper()
@@ -222,9 +223,10 @@ class MDict:
 			# decrypt if needed
 			if self._encrypt & 0x02:
 				key = ripemd128(key_block_info_compressed[4:8] + pack(b"<L", 0x3695))
-				key_block_info_compressed = key_block_info_compressed[
-					:8
-				] + _fast_decrypt(key_block_info_compressed[8:], key)
+				key_block_info_compressed = key_block_info_compressed[:8] + _fast_decrypt(
+					key_block_info_compressed[8:],
+					key,
+				)
 			# decompress
 			key_block_info = zlib.decompress(key_block_info_compressed[8:])
 			# adler checksum
@@ -673,7 +675,7 @@ class MDD(MDict):
 	def __init__(
 		self,
 		fname: str,
-		passcode: "tuple[bytes, bytes] | None" = None,
+		passcode: tuple[bytes, bytes] | None = None,
 	) -> None:
 		MDict.__init__(self, fname, encoding="UTF-16", passcode=passcode)
 
@@ -693,7 +695,7 @@ class MDX(MDict):
 		fname: str,
 		encoding: str = "",
 		substyle: bool = False,
-		passcode: "tuple[bytes, bytes] | None" = None,
+		passcode: tuple[bytes, bytes] | None = None,
 	) -> None:
 		MDict.__init__(self, fname, encoding, passcode)
 		self._substyle = substyle
@@ -718,9 +720,7 @@ class MDX(MDict):
 
 	def _treat_record_data(self, data):
 		# convert to utf-8
-		data = (
-			data.decode(self._encoding, errors="ignore").strip("\x00").encode("utf-8")
-		)
+		data = data.decode(self._encoding, errors="ignore").strip("\x00").encode("utf-8")
 		# substitute styles
 		if self._substyle and self._stylesheet:
 			data = self._substitute_stylesheet(data)
