@@ -13,12 +13,11 @@
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
-from __future__ import annotations
 
 """extended indexes generation with respect to source language."""
 
-import os
-import pkgutil
+from __future__ import annotations
+
 from typing import TYPE_CHECKING
 
 if TYPE_CHECKING:
@@ -27,18 +26,14 @@ if TYPE_CHECKING:
 __all__ = ["languages"]
 
 languages: dict[str, Callable[[Sequence[str], str], set[str]]] = {}
-"""
-submodules must register languages by adding (language name -> function)
-pairs to the mapping.
 
-function must follow signature below:
-	:param titles: flat iterable of title and altenrative titles
-	:param content: cleaned entry content
-	:return: iterable of indexes (str).
+# submodules must register languages by adding (language name -> function)
+# pairs to the mapping.
 
-"""
+# function must follow signature below:
+# 	:param titles: flat iterable of title and altenrative titles
+# 	:param content: cleaned entry content
+# 	:return: iterable of indexes (str).
 
-here = os.path.dirname(os.path.abspath(__file__))
-
-for _, module, _ in pkgutil.iter_modules([here]):  # type: ignore # noqa: PGH003
-	__import__(f"{__name__}.{module}")
+import pyglossary.plugins.appledict.indexes.ru  # noqa: F401
+import pyglossary.plugins.appledict.indexes.zh  # noqa: F401
