@@ -304,9 +304,7 @@ class Reader:
 	) -> str:
 		if not self._html:
 			# FIXME: this produces duplicate text for Idioms.dictionary, see #301
-			return "".join(
-				self.tostring(child) for child in entryElem.iterdescendants()
-			)
+			return "".join(self.tostring(child) for child in entryElem.iterdescendants())
 
 		entryElem.tag = "div"
 		for attr in list(entryElem.attrib):
@@ -604,8 +602,8 @@ class Reader:
 		self._keyTextData = keyTextData
 
 	def readResFile(self, fname: str, fpath: str, ext: str) -> EntryType:
-		with open(fpath, "rb") as _file:
-			data = _file.read()
+		with open(fpath, "rb") as file:
+			data = file.read()
 		if ext == ".css":
 			log.debug(f"substituting apple css: {fname}: {fpath}")
 			data = substituteAppleCSS(data)
