@@ -25,7 +25,7 @@ from __future__ import annotations
 import io
 import os
 import re
-from typing import TYPE_CHECKING, NamedTuple
+from typing import TYPE_CHECKING, Any, NamedTuple
 
 from pyglossary.core import log
 from pyglossary.option import (
@@ -171,7 +171,7 @@ class BGLGzipFile(GzipFile):
 		self,
 		fileobj: io.IOBase | None = None,
 		closeFileobj: bool = False,
-		**kwargs,  # noqa: ANN003
+		**kwargs: Any,
 	) -> None:
 		GzipFile.__init__(self, fileobj=fileobj, **kwargs)
 		self.closeFileobj = closeFileobj
@@ -189,9 +189,7 @@ class Block:
 		self.offset = -1
 
 	def __str__(self) -> str:
-		return (
-			f"Block type={self.type}, length={self.length}, len(data)={len(self.data)}"
-		)
+		return f"Block type={self.type}, length={self.length}, len(data)={len(self.data)}"
 
 
 class FileOffS(file):
@@ -493,17 +491,12 @@ class Reader:
 			if self.targetLang.name2:
 				glos.setInfo("targetLang2", self.targetLang.name2)
 		###
-		for attr in (
-			"defaultCharset",
-			"sourceCharset",
-			"targetCharset",
-			"defaultEncoding",
-			"sourceEncoding",
-			"targetEncoding",
-		):
-			value = getattr(self, attr, None)
-			if value:
-				glos.setInfo("bgl_" + attr, value)
+		glos.setInfo("bgl_defaultCharset", self.defaultCharset)
+		glos.setInfo("bgl_sourceCharset", self.sourceCharset)
+		glos.setInfo("bgl_targetCharset", self.targetCharset)
+		glos.setInfo("bgl_defaultEncoding", self.defaultEncoding)
+		glos.setInfo("bgl_sourceEncoding", self.sourceEncoding)
+		glos.setInfo("bgl_targetEncoding", self.targetEncoding)
 		###
 		glos.setInfo("sourceCharset", "UTF-8")
 		glos.setInfo("targetCharset", "UTF-8")
