@@ -2,9 +2,10 @@
 
 from __future__ import annotations
 
+import os
 from typing import TYPE_CHECKING
 
-from pyglossary.flags import ALWAYS
+from pyglossary.flags import ALWAYS, DEFAULT_YES
 from pyglossary.option import (
 	BoolOption,
 	IntOption,
@@ -49,6 +50,8 @@ website = None
 optionsProp: dict[str, Option] = {
 	"group_by_prefix_length": IntOption(
 		comment="Prefix length for grouping",
+		minim=1,
+		maxim=100,
 	),
 	# "group_by_prefix_merge_min_size": IntOption(),
 	# "group_by_prefix_merge_across_first": BoolOption(),
@@ -68,3 +71,6 @@ optionsProp: dict[str, Option] = {
 		comment="Path to cover file",
 	),
 }
+
+if os.getenv("PYGLOSSARY_EPUB_NO_FORCE_SORT") == "1":
+	sortOnWrite = DEFAULT_YES
