@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+from __future__ import annotations
 
 from typing import TYPE_CHECKING
 
@@ -14,7 +15,7 @@ if TYPE_CHECKING:
 __all__ = ["optionsProp"]
 
 
-optionsProp: "dict[str, Option]" = {
+optionsProp: dict[str, Option] = {
 	"resources": BoolOption(
 		comment="Enable resources / data files",
 	),
@@ -22,7 +23,6 @@ optionsProp: "dict[str, Option]" = {
 		comment="Find and show unsupported tags",
 	),
 	"auto_rtl": BoolOption(
-		allowNone=True,
 		comment="Auto-detect and mark Right-to-Left text",
 	),
 	"auto_comma": BoolOption(
@@ -44,5 +44,7 @@ optionsProp: "dict[str, Option]" = {
 	),
 	"example_padding": IntOption(
 		comment="Padding for examples (in px)",
+		minim=0,
+		maxim=10000,
 	),
 }
