@@ -14,7 +14,6 @@ from pyglossary.io_utils import nullBinaryIO
 from pyglossary.langs import langDict
 from pyglossary.langs.writing_system import getWritingSystemFromText
 
-from .options import optionsProp
 from .utils import XMLLANG, ReaderUtils
 
 if TYPE_CHECKING:
@@ -55,17 +54,25 @@ class Reader(ReaderUtils):
 	}
 
 	_discover: bool = False
-	_auto_rtl: bool | None = None
+	_auto_rtl: bool = True
 	_auto_comma: bool = True
 	_comma: str = ", "
 	_word_title: bool = False
 	_pron_color: str = "gray"
 	_gram_color: str = "green"
-
 	_example_padding: int = 10
 
-	gramClass = "grammar"
+	def _copyOptionsTo(self, other: Reader) -> None:
+		other._discover = self._discover
+		other._auto_rtl = self._auto_rtl
+		other._auto_comma = self._auto_comma
+		other._comma = self._comma
+		other._word_title = self._word_title
+		other._pron_color = self._pron_color
+		other._gram_color = self._gram_color
+		other._example_padding = self._example_padding
 
+	gramClass = "grammar"
 	supportedTags: set[str] = {
 		f"{_TEI}{tag}"
 		for tag in (
@@ -636,6 +643,16 @@ class Reader(ReaderUtils):
 		def br() -> Element:
 			return ET.Element("br")
 
+		def write_keywords_title(keywords: list[str]) -> None:
+			for keyword in keywords:
+				titleTag = glos.titleTag(keyword)
+				if titleTag:
+					with hf.element(titleTag):
+						hf.write(keyword)
+				else:
+					hf.write(keyword)
+				hf.write(br())
+
 		inflectedKeywords: list[str] = []
 
 		for form in entry.findall(".//form", _NAMESPACE):
@@ -660,10 +677,7 @@ class Reader(ReaderUtils):
 		with ET.htmlfile(buff, encoding="utf-8") as hf:
 			with hf.element("div"):
 				if self._word_title:
-					for keyword in keywords:
-						with hf.element(glos.titleTag(keyword)):
-							hf.write(keyword)
-						hf.write(br())
+					write_keywords_title(keywords)
 
 				# TODO: "form/usg"
 				# <usg type="geo">Brit</usg>
@@ -880,32 +894,21 @@ class Reader(ReaderUtils):
 			log.error(f"no such file {filename!r} from {elem}")
 			return None
 		reader = Reader(self._glos)
-		for optName in optionsProp:
-			attr = "_" + optName
-			if hasattr(self, attr):
-				setattr(reader, attr, getattr(self, attr))
+		self._copyOptionsTo(reader)
 		reader.open(filename)
 		return reader
 
 	def __iter__(self) -> Iterator[EntryType]:
 		from lxml import etree as ET
 
-		if self._auto_rtl is None:
-			glos = self._glos
-			if (glos.sourceLang and glos.sourceLang.rtl) or (
-				glos.targetLang and glos.targetLang.rtl
-			):
-				log.info("setting auto_rtl=True")
-				self._auto_rtl = True
-
 		self._file = compressionOpen(self._filename, mode="rb")
 		context = ET.iterparse(  # type: ignore # noqa: PGH003
 			self._file,
 			events=("end",),
 			tag=(_ENTRY, _INCLUDE),
 		)
-		for _, _elem in context:
-			elem = cast("Element", _elem)
+		for _, elem_ in context:
+			elem = cast("Element", elem_)
 
 			if elem.tag == _INCLUDE:
 				reader = self.loadInclude(elem)
