@@ -47,9 +47,11 @@ optionsProp: dict[str, Option] = {
 	),
 	"max_file_size": IntOption(
 		comment="Maximum file size in bytes",
+		minim=0,
+		maxim=1_000_0000_000,
 	),
 	"filename_format": StrOption(
-		comment="Filename format, default: {n:05d}.html",
+		comment="Filename format",
 	),
 	"escape_defi": BoolOption(
 		comment="Escape definitions",
