@@ -106,8 +106,8 @@ class Reader:
 			if not line:
 				continue
 			yield self.makeEntry(json_loads(line))
-		for _msg, count in self._warnings.most_common():
-			msg = _msg
+		for msg_, count in self._warnings.most_common():
+			msg = msg_
 			if count > 1:
 				msg = f"[{count} times] {msg}"
 			log.warning(msg)
@@ -124,6 +124,16 @@ class Reader:
 		def br() -> Element:
 			return ET.Element("br")
 
+		def write_keywords_title(keywords: list[str]) -> None:
+			for keyword in keywords:
+				titleTag = glos.titleTag(keyword)
+				if titleTag:
+					with hf.element(titleTag):
+						hf.write(keyword)
+				else:
+					hf.write(keyword)
+				hf.write(br())
+
 		keywords: list[str] = []
 		inflectedKeywords: list[str] = []
 
@@ -158,10 +168,7 @@ class Reader:
 		with ET.htmlfile(f, encoding="utf-8") as hf:
 			with hf.element("div"):
 				if self._word_title:
-					for keyword in keywords:
-						with hf.element(glos.titleTag(keyword)):
-							hf.write(keyword)
-						hf.write(br())
+					write_keywords_title(keywords)
 
 				hf_ = cast("T_htmlfile", hf)
 
@@ -273,15 +280,15 @@ class Reader:
 		if text:
 			hf.write(f"{text}: ")
 		with hf.element("audio", attrib={"controls": ""}):
-			for _format in self._audio_formats:
-				url = sound.get(f"{_format}_url")
+			for format_ in self._audio_formats:
+				url = sound.get(f"{format_}_url")
 				if not url:
 					continue
 				with hf.element(
 					"source",
 					attrib={
 						"src": url,
-						"type": f"audio/{_format}",
+						"type": f"audio/{format_}",
 					},
 				):
 					pass
