@@ -42,6 +42,7 @@ from typing import (
 	Any,
 	Generic,
 	NamedTuple,
+	Self,
 	TypeVar,
 	cast,
 )
@@ -152,6 +153,24 @@ class CompressionModule(typing.Protocol):
 		raise NotImplementedError
 
 
+def _load_bz2() -> Callable[[], CompressionModule]:
+	import bz2
+
+	return bz2
+
+
+def _load_zlib() -> Callable[[], CompressionModule]:
+	import zlib
+
+	return zlib
+
+
+_basicCompressionModules = {
+	"bz2": _load_bz2,
+	"zlib": _load_zlib,
+}
+
+
 def init_compressions() -> dict[str, Compression]:
 	def ident(x: bytes) -> bytes:
 		return x
@@ -159,10 +178,10 @@ def init_compressions() -> dict[str, Compression]:
 	compressions: dict[str, Compression] = {
 		"": Compression(ident, ident),
 	}
-	for name in ("bz2", "zlib"):
+	for name, loader in _basicCompressionModules.items():
 		m: CompressionModule
 		try:
-			m = cast("CompressionModule", __import__(name))
+			m = loader()
 		except ImportError:
 			warnings.showwarning(
 				message=f"{name} is not available",
@@ -271,7 +290,7 @@ class MultiFileReader(BufferedIOBase):
 		self._offset = -1
 		self.seek(0)
 
-	def __enter__(self) -> MultiFileReader:
+	def __enter__(self) -> Self:
 		return self
 
 	def __exit__(
@@ -348,46 +367,6 @@ class MultiFileReader(BufferedIOBase):
 		return result
 
 
-class KeydItemDict:
-	def __init__(
-		self,
-		blobs: Sequence[Blob | Ref],
-		strength: int,
-		maxlength: int | None = None,
-	) -> None:
-		self.blobs = blobs
-		self.sortkey = sortkey(strength, maxlength=maxlength)
-
-	def __len__(self) -> int:
-		return len(self.blobs)
-
-	# https://docs.python.org/3/library/bisect.html
-	# key= parameter to bisect_left is added in Python 3.10
-	def __getitem__(self, key: str) -> Iterator[Blob | Ref]:
-		blobs = self.blobs
-		key_as_sk = self.sortkey(key)
-		i = bisect_left(
-			blobs,
-			key_as_sk,
-			key=lambda blob: self.sortkey(blob.key),
-		)
-		if i == len(blobs):
-			return
-		while i < len(blobs):
-			if self.sortkey(blobs[i].key) == key_as_sk:
-				yield blobs[i]
-			else:
-				break
-			i += 1
-
-	def __contains__(self, key: str) -> bool:
-		try:
-			next(self[key])
-		except StopIteration:
-			return False
-		return True
-
-
 class Blob:
 	def __init__(  # noqa: PLR0913
 		self,
@@ -432,6 +411,46 @@ class Blob:
 		return f"<{self.__class__.__module__}.{self.__class__.__name__} {self.key}>"
 
 
+class KeydItemDict:
+	def __init__(
+		self,
+		blobs: Sequence[Blob | Ref],
+		strength: int,
+		maxlength: int | None = None,
+	) -> None:
+		self.blobs = blobs
+		self.sortkey = sortkey(strength, maxlength=maxlength)
+
+	def __len__(self) -> int:
+		return len(self.blobs)
+
+	# https://docs.python.org/3/library/bisect.html
+	# key= parameter to bisect_left is added in Python 3.10
+	def __getitem__(self, key: str) -> Iterator[Blob | Ref]:
+		blobs = self.blobs
+		key_as_sk = self.sortkey(key)
+		i = bisect_left(
+			blobs,
+			key_as_sk,
+			key=lambda blob: self.sortkey(blob.key),
+		)
+		if i == len(blobs):
+			return
+		while i < len(blobs):
+			if self.sortkey(blobs[i].key) == key_as_sk:
+				yield blobs[i]
+			else:
+				break
+			i += 1
+
+	def __contains__(self, key: str) -> bool:
+		try:
+			next(self[key])
+		except StopIteration:
+			return False
+		return True
+
+
 def read_byte_string(f: IOBase, len_spec: str) -> bytes:
 	length = unpack(len_spec, f.read(calcsize(len_spec)))[0]
 	return f.read(length)
@@ -677,7 +696,7 @@ class Slob:
 			self._header.content_types,
 		)
 
-	def __enter__(self) -> Slob:
+	def __enter__(self) -> Self:
 		return self
 
 	def __exit__(
@@ -1476,17 +1495,17 @@ class Writer:
 		return cast("Slob", self)
 
 	def close(self) -> None:
-		for _file in (
+		for file in (
 			self.f_ref_positions,
 			self.f_refs,
 			self.f_store_positions,
 			self.f_store,
 		):
-			if _file is None:
+			if file is None:
 				continue
 			self._fire_event("WARNING: closing without finalize()")
 			try:
-				_file.close()
+				file.close()
 			except Exception:
 				pass
 		if self.tmpdir and isdir(self.tmpdir.name):
