@@ -18,17 +18,24 @@
 
 from __future__ import annotations
 
+import ast
 import logging
 import traceback
-from os.path import abspath, isfile
-from typing import TYPE_CHECKING, Any
+from os.path import isfile
+from typing import TYPE_CHECKING, Any, Protocol
 
 import gi
 
 from pyglossary.core import homePage, pip
 from pyglossary.glossary_v2 import ConvertArgs, Error, Glossary
+from pyglossary.option import Option
+from pyglossary.os_utils import abspath2
 from pyglossary.sort_keys import defaultSortKeyName, namedSortKeyList
-from pyglossary.text_utils import urlToPath
+from pyglossary.text_utils import (
+	escapeNRB,
+	unescapeNRB,
+	urlToPath,
+)
 
 from .base import (
 	UIBase,
@@ -67,6 +74,8 @@ if TYPE_CHECKING:
 
 # from gi.repository import GdkPixbuf
 
+__all__ = ["UI"]
+
 log = logging.getLogger("pyglossary")
 
 glib.set_prgname("PyGlossary (Gtk3)")
@@ -76,9 +85,7 @@ gtk.Window.set_default_icon_from_file(logo)
 _ = str  # later replace with translator function
 
 pluginByDesc = {plugin.description: plugin for plugin in Glossary.plugins.values()}
-readDesc = [
-	plugin.description for plugin in Glossary.plugins.values() if plugin.canRead
-]
+readDesc = [plugin.description for plugin in Glossary.plugins.values() if plugin.canRead]
 writeDesc = [
 	plugin.description for plugin in Glossary.plugins.values() if plugin.canWrite
 ]
@@ -118,7 +125,7 @@ class FormatDialog(gtk.Dialog):
 		self,
 		descList: list[str],
 		parent: gtk.Widget | None = None,
-		**kwargs,
+		**kwargs: Any,
 	) -> None:
 		gtk.Dialog.__init__(self, parent=parent, **kwargs)
 		self.descList = descList
@@ -310,17 +317,245 @@ class FormatButton(gtk.Button):
 		self.onChanged()
 
 
+class OptionTkType(Protocol):
+	def __init__(self, opt: Option) -> None: ...
+	@property
+	def value(self) -> Any: ...
+	@value.setter
+	def value(self, x: Any) -> None: ...
+	@property
+	def widget(self) -> gtk.Widget: ...
+
+
+class BoolOptionGtk:
+	def __init__(self, opt: Option) -> None:
+		hbox = HBox()
+		cb = gtk.CheckButton(
+			label=f"{opt.displayName} ({opt.comment})",
+		)
+		pack(hbox, cb)
+		self._hbox = hbox
+		self._cb = cb
+
+	@property
+	def value(self) -> Any:
+		return self._cb.get_active()
+
+	@value.setter
+	def value(self, x: Any) -> None:
+		self._cb.set_active(bool(x))
+
+	@property
+	def widget(self) -> gtk.Widget:
+		return self._hbox
+
+
+class IntOptionGtk:
+	def __init__(self, opt: Option) -> None:
+		hbox = HBox()
+		pack(
+			hbox,
+			gtk.Label(label=f"{opt.displayName}: "),
+		)
+		minim = opt.minim
+		if minim is None:
+			minim = 0
+		maxim = opt.maxim
+		if maxim is None:
+			maxim = 1_000_000_000
+		spin = gtk.SpinButton()
+		spin.set_digits(0)
+		spin.set_range(minim, maxim)
+		spin.set_increments(1, 10)
+		# spin.set_width_chars
+		pack(hbox, spin)
+		self._hbox = hbox
+		self._spin = spin
+
+	@property
+	def value(self) -> Any:
+		return int(self._spin.get_value())
+
+	@value.setter
+	def value(self, x: Any) -> None:
+		self._spin.set_value(int(x))
+
+	@property
+	def widget(self) -> gtk.Widget:
+		return self._hbox
+
+
+class StrOptionGtk:
+	def __init__(self, opt: Option) -> None:
+		self.opt = opt
+		hbox = HBox()
+		pack(
+			hbox,
+			gtk.Label(label=f"{opt.displayName} ({opt.comment}): "),
+		)
+		self._hbox = hbox
+		if opt.customValue:
+			combo = gtk.ComboBoxText.new_with_entry()
+		else:
+			combo = gtk.ComboBoxText.new()
+		self._combo = combo
+		pack(hbox, combo)
+		if opt.values:
+			for value in opt.values:
+				combo.append_text(value)
+			self._width = max(len(x) for x in opt.values)
+		else:
+			self._width = 10
+		combo.get_child().set_width_chars(self._width)
+
+	@property
+	def value(self) -> Any:
+		return self._combo.get_active_text()
+
+	@value.setter
+	def value(self, x: Any) -> None:
+		st = str(x)
+		values = self.opt.values or []
+		try:
+			index = values.index(st)
+		except ValueError:
+			self._combo.append_text(st)
+			index = len(self._combo.get_model()) - 1
+		self._combo.set_active(index)
+		if len(st) > self._width:
+			self._width = len(st)
+			self._combo.get_child().set_width_chars(len(st))
+
+	@property
+	def widget(self) -> gtk.Widget:
+		return self._hbox
+
+
+class FileSizeOptionGtk(StrOptionGtk):
+	pass
+
+
+class HtmlColorOptionGtk(StrOptionGtk):
+	pass
+
+
+class MultiLineStrOptionGtk:
+	def __init__(self, opt: Option) -> None:
+		hbox = HBox()
+		pack(
+			hbox,
+			gtk.Label(label=f"{opt.displayName} ({opt.comment}): "),
+		)
+		tview = gtk.TextView()
+		frame = gtk.Frame()
+		frame.add(tview)
+		pack(hbox, frame, expand=True, fill=True)
+		self._hbox = hbox
+		self._buf = tview.get_buffer()
+
+	@property
+	def value(self) -> Any:
+		return self._buf.get_text(
+			start=self._buf.get_start_iter(),
+			end=self._buf.get_end_iter(),
+			include_hidden_chars=True,
+		)
+
+	@value.setter
+	def value(self, x: Any) -> None:
+		self._buf.set_text(str(x))
+
+	@property
+	def widget(self) -> gtk.Widget:
+		return self._hbox
+
+
+class NewlineOptionGtk:
+	def __init__(self, opt: Option) -> None:
+		self.opt = opt
+		hbox = HBox()
+		pack(
+			hbox,
+			gtk.Label(
+				label=f"{opt.displayName} ({opt.comment}, escaped \\n\\r): ",
+			),
+		)
+		self._hbox = hbox
+		combo = gtk.ComboBoxText.new_with_entry()
+		for value in opt.values:
+			combo.append_text(escapeNRB(value))
+		self._combo = combo
+		pack(hbox, combo)
+		combo.get_child().set_width_chars(5)
+
+	@property
+	def value(self) -> Any:
+		return unescapeNRB(self._combo.get_active_text())
+
+	@value.setter
+	def value(self, x: Any) -> None:
+		st = escapeNRB(str(x))
+		values = self.opt.values or []
+		try:
+			index = values.index(st)
+		except ValueError:
+			self._combo.append_text(st)
+			index = len(self._combo.get_model()) - 1
+		self._combo.set_active(index)
+
+	@property
+	def widget(self) -> gtk.Widget:
+		return self._hbox
+
+
+class LiteralEvalOptionGtk(MultiLineStrOptionGtk):
+	@property
+	def value(self) -> Any:
+		return ast.literal_eval(self._buf.get_text())
+
+	@value.setter
+	def value(self, x: Any) -> None:
+		self._buf.set_text(repr(x))
+
+
+class ListOptionGtk(LiteralEvalOptionGtk):
+	typeHint = "Python list"
+
+
+class DictOptionGtk(LiteralEvalOptionGtk):
+	typeHint = "Python dict"
+
+
+optionClassByName: dict[str, OptionTkType] = {
+	"BoolOption": BoolOptionGtk,
+	"IntOption": IntOptionGtk,
+	"StrOption": StrOptionGtk,
+	"EncodingOption": StrOptionGtk,
+	"FileSizeOption": FileSizeOptionGtk,
+	"UnicodeErrorsOption": StrOptionGtk,
+	"HtmlColorOption": HtmlColorOptionGtk,
+	"NewlineOption": NewlineOptionGtk,
+	"ListOption": ListOptionGtk,
+	"DictOption": DictOptionGtk,
+	# "FloatOption": FloatOptionGtk,  # not used so far!
+}
+
+
 class FormatOptionsDialog(gtk.Dialog):
 	commentLen = 60
+	kindFormatsOptions = {
+		"r": Glossary.formatsReadOptions,
+		"w": Glossary.formatsWriteOptions,
+	}
 
 	def __init__(
 		self,
 		formatName: str,
-		options: list[str],
-		optionsValues: dict[str, Any],
-		parent: gtk.Widget | None = None,
+		kind: str,  # "r" or "w"
+		values: dict[str, Any],
+		transient_for: gtk.Window | None = None,
 	) -> None:
-		gtk.Dialog.__init__(self, parent=parent)
+		gtk.Dialog.__init__(self, transient_for=transient_for)
 		optionsProp = Glossary.plugins[formatName].optionsProp
 		self.optionsProp = optionsProp
 		##
@@ -338,260 +573,33 @@ class FormatOptionsDialog(gtk.Dialog):
 			gtk.ResponseType.OK,
 		)
 		###
-		treev = gtk.TreeView()
-		treeModel = gtk.ListStore(
-			bool,  # enable
-			str,  # name
-			str,  # comment
-			str,  # value
-		)
-		treev.set_headers_clickable(True)
-		treev.set_model(treeModel)
-		treev.connect("row-activated", self.rowActivated)
-		treev.connect("button-press-event", self.treeviewButtonPress)
-		###
-		self.treev = treev
-		#############
-		cell = gtk.CellRendererToggle()
-		# cell.set_property("activatable", True)
-		cell.connect("toggled", self.enableToggled)
-		col = gtk.TreeViewColumn(title="Enable", cell_renderer=cell)
-		col.add_attribute(cell, "active", 0)
-		# cell.set_active(False)
-		col.set_property("expand", False)
-		col.set_resizable(True)
-		treev.append_column(col)
-		###
-		col = gtk.TreeViewColumn(
-			title="Name",
-			cell_renderer=gtk.CellRendererText(),
-			text=1,
-		)
-		col.set_property("expand", False)
-		col.set_resizable(True)
-		treev.append_column(col)
-		###
-		cell = gtk.CellRendererText(editable=True)
-		self.valueCell = cell
-		self.valueCol = 3
-		cell.connect("edited", self.valueEdited)
-		col = gtk.TreeViewColumn(
-			title="Value",
-			cell_renderer=cell,
-			text=self.valueCol,
-		)
-		col.set_property("expand", True)
-		col.set_resizable(True)
-		col.set_min_width(200)
-		treev.append_column(col)
-		###
-		col = gtk.TreeViewColumn(
-			title="Comment",
-			cell_renderer=gtk.CellRendererText(),
-			text=2,
-		)
-		col.set_property("expand", False)
-		col.set_resizable(False)
-		treev.append_column(col)
-		#############
-		for name in options:
-			prop = optionsProp[name]
+		self.options = self.kindFormatsOptions[kind][formatName]
+		self.values = values
+		self.widgets: dict[str, OptionTkType] = {}
+		self.createOptionsList()
+		############
+		self.vbox.show_all()
+
+	def createOptionsList(self) -> None:
+		values = self.values
+		for optName, default in self.options.items():
+			prop = self.optionsProp[optName]
 			comment = prop.longComment
 			if len(comment) > self.commentLen:
 				comment = comment[: self.commentLen] + "..."
-			if prop.typ != "bool" and not prop.values:
-				comment += " (double-click to edit)"
-			treeModel.append(
-				[
-					name in optionsValues,  # enable
-					name,  # name
-					comment,  # comment
-					str(optionsValues.get(name, "")),  # value
-				],
-			)
-		############
-		pack(self.vbox, treev, 1, 1)
-		self.vbox.show_all()
-
-	def enableToggled(self, cell: gtk.CellRenderer, path: gtk.TreePath) -> None:
-		# enable is column 0
-		model = self.treev.get_model()
-		active = not cell.get_active()
-		itr = model.get_iter(path)
-		model.set_value(itr, 0, active)
-
-	def valueEdited(
-		self,
-		_cell: gtk.CellRenderer,
-		path: gtk.TreePath,
-		rawValue: str,
-	) -> None:
-		# value is column 3
-		model = self.treev.get_model()
-		itr = model.get_iter(path)
-		optName = model.get_value(itr, 1)
-		prop = self.optionsProp[optName]
-		if not prop.customValue:
-			return
-		enable = True
-		if rawValue == "" and prop.typ != "str":  # noqa: PLC1901
-			enable = False
-		elif not prop.validateRaw(rawValue):
-			log.error(f"invalid {prop.typ} value: {optName} = {rawValue!r}")
-			return
-		model.set_value(itr, self.valueCol, rawValue)
-		model.set_value(itr, 0, enable)
-
-	def rowActivated(
-		self,
-		_treev: gtk.Widget,
-		path: gtk.TreePath,
-		_col: gtk.TreeViewColumn,
-	) -> bool:
-		# forceMenu=True because we can not enter edit mode
-		# if double-clicked on a cell other than Value
-		return self.valueCellClicked(path, forceMenu=True)
-
-	def treeviewButtonPress(self, treev: gtk.TreeView, gevent: gdk.ButtonEvent) -> bool:
-		if gevent.button != 1:
-			return False
-		pos_t = treev.get_path_at_pos(int(gevent.x), int(gevent.y))
-		if not pos_t:
-			return False
-		# pos_t == path, col, xRel, yRel
-		path = pos_t[0]
-		col = pos_t[1]
-		# cell = col.get_cells()[0]
-		if col.get_title() == "Value":
-			return self.valueCellClicked(path)
-		return False
-
-	def valueItemActivate(self, item: gtk.MenuItem, itr: gtk.TreeIter) -> None:
-		# value is column 3
-		value = item.get_label()
-		model = self.treev.get_model()
-		model.set_value(itr, self.valueCol, value)
-		model.set_value(itr, 0, True)  # enable it
-
-	def valueCustomOpenDialog(self, itr: gtk.TreeIter, optName: str) -> None:
-		model = self.treev.get_model()
-		prop = self.optionsProp[optName]
-		currentValue = model.get_value(itr, self.valueCol)
-		optDesc = optName
-		if prop.comment:
-			optDesc += f" ({prop.comment})"
-		label = gtk.Label(label=f"Value for {optDesc}")
-		dialog = gtk.Dialog(parent=self, title="Option Value")
-		dialog.connect("response", lambda _w, _e: dialog.hide())
-		dialog_add_button(
-			dialog,
-			"gtk-cancel",
-			"_Cancel",
-			gtk.ResponseType.CANCEL,
-		)
-		dialog_add_button(
-			dialog,
-			"gtk-ok",
-			"_OK",
-			gtk.ResponseType.OK,
-		)
-		pack(dialog.vbox, label, 0, 0)
-		entry = gtk.Entry()
-		entry.set_text(currentValue)
-		entry.connect("activate", lambda _w: dialog.response(gtk.ResponseType.OK))
-		pack(dialog.vbox, entry, 0, 0)
-		dialog.vbox.show_all()
-		if dialog.run() != gtk.ResponseType.OK:
-			return
-		value = entry.get_text()
-		model.set_value(itr, self.valueCol, value)
-		model.set_value(itr, 0, True)  # enable it
-
-	def valueItemCustomActivate(
-		self,
-		_item: gtk.MenuItem,
-		itr: gtk.TreeIter,
-	) -> None:
-		model = self.treev.get_model()
-		optName = model.get_value(itr, 1)
-		self.valueCustomOpenDialog(itr, optName)
-
-	def valueCellClicked(self, path: gtk.TreePath, forceMenu: bool = False) -> bool:
-		"""
-		Returns True if event is handled, False if not handled
-		(need to enter edit mode).
-		"""
-		model = self.treev.get_model()
-		itr = model.get_iter(path)
-		optName = model.get_value(itr, 1)
-		prop = self.optionsProp[optName]
-		if prop.typ == "bool":
-			rawValue = model.get_value(itr, self.valueCol)
-			if rawValue == "":  # noqa: PLC1901
-				value = False
-			else:
-				value, isValid = prop.evaluate(rawValue)
-				if not isValid:
-					log.error(f"invalid {optName} = {rawValue!r}")
-					value = False
-			model.set_value(itr, self.valueCol, str(not value))
-			model.set_value(itr, 0, True)  # enable it
-			return True
-		propValues = prop.values
-		if not propValues:
-			if forceMenu:
-				propValues = []
-			else:
-				return False
-		menu = gtk.Menu()
-		if prop.customValue:
-			item = gtk.MenuItem("[Custom Value]")
-			item.connect("activate", self.valueItemCustomActivate, itr)
-			item.show()
-			menu.append(item)
-		groupedValues = None
-		if len(propValues) > 10:
-			groupedValues = prop.groupValues()
-		if groupedValues:
-			for groupName, values in groupedValues.items():
-				item = gtk.MenuItem()
-				item.set_label(groupName)
-				if values is None:
-					item.connect("activate", self.valueItemActivate, itr)
-				else:
-					subMenu = gtk.Menu()
-					for subValue in values:
-						subItem = gtk.MenuItem(label=str(subValue))
-						subItem.connect("activate", self.valueItemActivate, itr)
-						subItem.show()
-						subMenu.append(subItem)
-					item.set_submenu(subMenu)
-				item.show()
-				menu.append(item)
-		else:
-			for value in propValues:
-				item = gtk.MenuItem(value)
-				item.connect("activate", self.valueItemActivate, itr)
-				item.show()
-				menu.append(item)
-		etime = gtk.get_current_event_time()
-		menu.popup(None, None, None, None, 3, etime)
-		return True
+			widgetClass = optionClassByName.get(prop.__class__.__name__)
+			if widgetClass is None:
+				log.warning(f"No widget class for option class {prop.__class__}")
+				continue
+			w = widgetClass(prop)
+			pack(self.vbox, w.widget)
+			w.value = values.get(optName, default)
+			self.widgets[optName] = w
 
 	def getOptionsValues(self) -> dict[str, Any]:
-		model = self.treev.get_model()
 		optionsValues: dict[str, Any] = {}
-		for row in model:
-			if not row[0]:  # not enable
-				continue
-			optName = row[1]
-			rawValue = row[3]
-			prop = self.optionsProp[optName]
-			value, isValid = prop.evaluate(rawValue)
-			if not isValid:
-				log.error(f"invalid option value {optName} = {rawValue}")
-				continue
-			optionsValues[optName] = value
+		for optName, widget in self.widgets.items():
+			optionsValues[optName] = widget.value
 		return optionsValues
 
 
@@ -627,7 +635,7 @@ class FormatBox(FormatButton):
 		"""Return 'r' or 'w'."""
 		raise NotImplementedError
 
-	def getActiveOptions(self) -> list[str] | None:
+	def getActiveOptions(self) -> dict[str, Any] | None:
 		raise NotImplementedError
 
 	def hasOptions(self) -> bool:
@@ -639,10 +647,10 @@ class FormatBox(FormatButton):
 		if options is None:
 			return
 		dialog = FormatOptionsDialog(
-			formatName,
-			options,
-			self.optionsValues,
-			parent=self._parent,
+			formatName=formatName,
+			kind=self.kind(),
+			values=self.optionsValues,
+			transient_for=self._parent,
 		)
 		dialog.set_title("Options for " + formatName)
 		if dialog.run() != gtk.ResponseType.OK:
@@ -696,35 +704,35 @@ class FormatBox(FormatButton):
 class InputFormatBox(FormatBox):
 	dialogTitle = "Select Input Format"
 
-	def __init__(self, **kwargs) -> None:
+	def __init__(self, **kwargs: Any) -> None:
 		FormatBox.__init__(self, readDesc, **kwargs)
 
 	def kind(self) -> str:
 		"""Return 'r' or 'w'."""
 		return "r"
 
-	def getActiveOptions(self) -> list[str] | None:
+	def getActiveOptions(self) -> dict[str, Any] | None:
 		formatName = self.getActive()
 		if not formatName:
 			return None
-		return list(Glossary.formatsReadOptions[formatName])
+		return Glossary.formatsReadOptions[formatName]
 
 
 class OutputFormatBox(FormatBox):
 	dialogTitle = "Select Output Format"
 
-	def __init__(self, **kwargs) -> None:
+	def __init__(self, **kwargs: Any) -> None:
 		FormatBox.__init__(self, writeDesc, **kwargs)
 
 	def kind(self) -> str:
 		"""Return 'r' or 'w'."""
 		return "w"
 
-	def getActiveOptions(self) -> list[str] | None:
+	def getActiveOptions(self) -> dict[str, Any] | None:
 		formatName = self.getActive()
 		if not formatName:
 			return None
-		return list(Glossary.formatsWriteOptions[formatName])
+		return Glossary.formatsWriteOptions[formatName]
 
 
 class GtkTextviewLogHandler(logging.Handler):
@@ -837,8 +845,8 @@ class BrowseButton(gtk.Button):
 		fcd.destroy()
 
 
-sortKeyNameByDesc = {_sk.desc: _sk.name for _sk in namedSortKeyList}
-sortKeyNames = [_sk.name for _sk in namedSortKeyList]
+sortKeyNameByDesc = {sk.desc: sk.name for sk in namedSortKeyList}
+sortKeyNames = [sk.name for sk in namedSortKeyList]
 
 
 class SortOptionsBox(gtk.Box):
@@ -849,8 +857,8 @@ class SortOptionsBox(gtk.Box):
 		hbox = gtk.HBox()
 		sortCheck = gtk.CheckButton("Sort entries by")
 		sortKeyCombo = gtk.ComboBoxText()
-		for _sk in namedSortKeyList:
-			sortKeyCombo.append_text(_sk.desc)
+		for sk in namedSortKeyList:
+			sortKeyCombo.append_text(sk.desc)
 		sortKeyCombo.set_active(sortKeyNames.index(defaultSortKeyName))
 		sortKeyCombo.set_border_width(0)
 		sortKeyCombo.set_sensitive(False)
@@ -863,7 +871,7 @@ class SortOptionsBox(gtk.Box):
 		pack(self, hbox, 0, 0, padding=5)
 		###
 		hbox = self.encodingHBox = gtk.HBox()
-		encodingCheck = self.encodingCheck = gtk.CheckButton(label="Sort Encoding")
+		encodingCheck = self.encodingCheck = gtk.RadioButton(label="Sort Encoding")
 		encodingEntry = self.encodingEntry = gtk.Entry()
 		encodingEntry.set_text("utf-8")
 		encodingEntry.set_width_chars(15)
@@ -872,22 +880,16 @@ class SortOptionsBox(gtk.Box):
 		pack(hbox, encodingEntry, 0, 0, padding=5)
 		pack(self, hbox, 0, 0, padding=5)
 		###
-		# RadioButton in Gtk3 is very unstable,
-		# I could not make set_group work at all!
-		# encodingRadio.get_group() == [encodingRadio]
-		# localeRadio.set_group(encodingRadio) says:
-		#     TypeError: Must be sequence, not RadioButton
-		# localeRadio.set_group([encodingRadio]) causes a crash!!
-		# but localeRadio.join_group(encodingRadio) works,
-		#     so does group= argument to RadioButton()
-		# Note: RadioButton does not exist in Gtk 4.0,
-		# you have to use CheckButton with its new set_group() method
-
 		hbox = self.localeHBox = gtk.HBox()
 		localeEntry = self.localeEntry = gtk.Entry()
 		localeEntry.set_width_chars(15)
+		localeEntry.set_text("latin")
 		pack(hbox, gtk.Label(label="    "))
-		pack(hbox, gtk.Label(label="Sort Locale"), 0, 0)
+		self.localeCheck = gtk.RadioButton(
+			label="Sort Locale",
+			group=self.encodingCheck,
+		)
+		pack(hbox, self.localeCheck, 0, 0)
 		pack(hbox, localeEntry, 0, 0, padding=5)
 		pack(self, hbox, 0, 0, padding=5)
 		###
@@ -901,22 +903,24 @@ class SortOptionsBox(gtk.Box):
 
 	def updateWidgets(self) -> None:
 		convertOptions = self.ui.convertOptions
-		sort = convertOptions.get("sort")
+		sort = bool(convertOptions.get("sort", False))
 		self.sortCheck.set_active(sort)
 		self.sortKeyCombo.set_sensitive(sort)
 		self.encodingHBox.set_sensitive(sort)
 		self.localeHBox.set_sensitive(sort)
 
+		if "sortEncoding" in convertOptions:
+			self.encodingCheck.set_active(True)
+			self.encodingEntry.set_text(convertOptions["sortEncoding"])
+
 		sortKeyName = convertOptions.get("sortKeyName")
 		if sortKeyName:
 			sortKeyName, _, localeName = sortKeyName.partition(":")
 			if sortKeyName:
 				self.sortKeyCombo.set_active(sortKeyNames.index(sortKeyName))
 			self.localeEntry.set_text(localeName)
-
-		if "sortEncoding" in convertOptions:
-			self.encodingCheck.set_active(True)
-			self.encodingEntry.set_text(convertOptions["sortEncoding"])
+			if localeName:
+				self.localeCheck.set_active(True)
 
 	def applyChanges(self) -> None:
 		convertOptions = self.ui.convertOptions
@@ -927,17 +931,21 @@ class SortOptionsBox(gtk.Box):
 					del convertOptions[param]
 			return
 
+		convertOptions["sort"] = True
+
 		sortKeyDesc = self.sortKeyCombo.get_active_text()
 		sortKeyName = sortKeyNameByDesc[sortKeyDesc]
-		sortLocale = self.localeEntry.get_text()
-		if sortLocale:
-			sortKeyName = f"{sortKeyName}:{sortLocale}"
-
-		convertOptions["sort"] = True
-		convertOptions["sortKeyName"] = sortKeyName
-		if self.encodingCheck.get_active():
+		if self.localeCheck.get_active():
+			sortLocale = self.localeEntry.get_text()
+			if sortLocale:
+				sortKeyName = f"{sortKeyName}:{sortLocale}"
+				if "sortEncoding" in convertOptions:
+					del convertOptions["sortEncoding"]
+		elif self.encodingCheck.get_active():
 			convertOptions["sortEncoding"] = self.encodingEntry.get_text()
 
+		convertOptions["sortKeyName"] = sortKeyName
+
 
 class GeneralOptionsDialog(gtk.Dialog):
 	def onDeleteEvent(self, _widget: gtk.Widget, _event: gdk.Event) -> bool:
@@ -949,7 +957,7 @@ class GeneralOptionsDialog(gtk.Dialog):
 		self.hide()
 		return True
 
-	def __init__(self, ui: UI, **kwargs) -> None:
+	def __init__(self, ui: UI, **kwargs: Any) -> None:
 		gtk.Dialog.__init__(
 			self,
 			transient_for=ui,
@@ -1045,20 +1053,20 @@ class OptionsButton(gtk.MenuButton):
 		###
 		menu = gtk.Menu()
 		##
-		itemGeneral = gtk.MenuItem("General Options")
-		itemGeneral.connect("activate", self._onGeneralOptionClick)
-		menu.append(itemGeneral)
-		##
-		self.itemRead = gtk.MenuItem("Input Options")
+		self.itemRead = gtk.MenuItem("Read Options")
 		self.itemRead.connect("activate", onReadOptionClick)
 		self.itemRead.set_sensitive(False)
 		menu.append(self.itemRead)
 		##
-		self.itemWrite = gtk.MenuItem("Output Options")
+		self.itemWrite = gtk.MenuItem("Write Options")
 		self.itemWrite.connect("activate", onWriteOptionClick)
 		self.itemWrite.set_sensitive(False)
 		menu.append(self.itemWrite)
 		##
+		itemGeneral = gtk.MenuItem("General Options")
+		itemGeneral.connect("activate", self._onGeneralOptionClick)
+		menu.append(itemGeneral)
+		##
 		menu.show_all()
 		self.set_popup(menu)
 
@@ -1094,7 +1102,7 @@ class UI(UIBase, gtk.Application):
 		self.progressTitle = ""
 		self.mainWin: MainWindow | None = None
 
-	def run(self, **kwargs) -> None:
+	def run(self, **kwargs: Any) -> None:
 		self.runArgs = kwargs
 		gtk.Application.run(self)
 
@@ -1420,9 +1428,17 @@ class MainWindow(gtk.Dialog):
 		self.config = config
 
 		if inputFilename:
-			self.convertInputEntry.set_text(abspath(inputFilename))
+			self.convertInputEntry.set_text(abspath2(inputFilename))
 		if outputFilename:
-			self.convertOutputEntry.set_text(abspath(outputFilename))
+			self.convertOutputEntry.set_text(abspath2(outputFilename))
+
+		if inputFormat and inputFormat not in Glossary.readFormats:
+			log.error(f"invalid {inputFormat=}")
+			inputFormat = ""
+
+		if outputFormat and outputFormat not in Glossary.writeFormats:
+			log.error(f"invalid {outputFormat=}")
+			outputFormat = ""
 
 		if inputFormat:
 			self.inputFormatBox.setActive(inputFormat)
@@ -1481,6 +1497,7 @@ class MainWindow(gtk.Dialog):
 			gtk.main_iteration_do(False)
 
 		self.convertButton.set_sensitive(False)
+		self.optionsButton.set_sensitive(False)
 		self.progressTitle = "Converting"
 		readOptions = self.inputFormatBox.optionsValues
 		writeOptions = self.outputFormatBox.optionsValues
@@ -1517,6 +1534,7 @@ class MainWindow(gtk.Dialog):
 
 		finally:
 			self.convertButton.set_sensitive(True)
+			self.optionsButton.set_sensitive(True)
 			self.assert_quit = False
 			self.progressTitle = ""
 
